@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: pandoc-citeproc
 version: 0.9.1.1
-id: pandoc-citeproc-0.9.1.1-549a0472ef347a7ec97a56008c4d2d94
-key: pando_IkCKW0AHud43SreoHWxSTT
+id: pandoc-citeproc-0.9.1.1-5748d0995df6dc75a64f38e63a91d870
+key: pando_JW9rI2qTRiW07pRFtMLBgI
 license: BSD3
 maintainer: jgm@berkeley.edu
 homepage: https://github.com/jgm/pandoc-citeproc
@@ -42,32 +42,32 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-citeproc-0.9.1.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-citeproc-0.9.1.1
 data-dir: /usr/share/pandoc-citeproc
-hs-libraries: HSpandoc-citeproc-0.9.1.1-IkCKW0AHud43SreoHWxSTT
+hs-libraries: HSpandoc-citeproc-0.9.1.1-JW9rI2qTRiW07pRFtMLBgI
 depends:
-    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
+    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
+    data-default-0.6.0-4c4f075845d560f7a31d444f67905db9
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
     hs-bibutils-5.5-91f8c150a94b021e3f1d7580075e1ca0
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
-    pandoc-1.17.0.3-eb510c613bb58261320cda2a21b65c87
-    pandoc-types-1.16.1-5c682c2b5cffa962280d4abd090bac44
-    parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
+    pandoc-1.17.0.3-385c8e8a07c6129d5c295aa0dcb411ba
+    pandoc-types-1.16.1-30bcf2ba2a8f2fe5e0ad6c109c33aa1e
+    parsec-3.1.11-2df9dc070a05b018377712731c5dde62
     setenv-0.1.1.3-4d70f2e61b1bd0645017164a0ca26ee9
-    split-0.2.3-1755fd7a4bff52537a62f0056f73dfbc
+    split-0.2.3.1-720861915f5bd1738e9c1363195cfb8f
     syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
-    tagsoup-0.13.9-61f7129b459feb0b7d9b7f0c4b3300d3
+    tagsoup-0.13.10-e0607642a7a600be1f9d9bab46fd617e
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     text-icu-0.7.0.1-5ca732f0eac6589810e9e4239ad6c2ab
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
-    xml-conduit-1.3.4.1-75d80fe52680bbdca276c9f509509d3e
-    yaml-0.8.17-256008eb42bc8c59588e1e26ecb14272
+    xml-conduit-1.3.5-b0d7925ea0f1a62fe18b3cdd25dd3416
+    yaml-0.8.17.1-e4e3d8aa5aa8eb9fbd84f744946960bc
 haddock-interfaces: /usr/share/doc/pandoc-citeproc/html/pandoc-citeproc.haddock
 haddock-html: /usr/share/doc/pandoc-citeproc/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
